#!/usr/bin/perl
# +========================================================================+
# || CAT CipUX Administration Tool                                        ||
# || Webmin module: setup.cgi                                        ||
# || for administration of CAT and CipUX                                  ||
# || (c) 2001,2002,2003,2005 by Christian Kuelker                         ||
# || License: GPLv2                                                       ||
# +========================================================================+

package setup_cgi;

do '../web-lib.pl';
&init_config();

use CipUX::CiBot;
use CipUX::Cat;
use CipUX::Task;

my $BRAND    = "cipworx";
my $PROJECT  = "cipux";
my $SCRIPT   = "setup.cgi";


my $last_question = 0;

&log($SCRIPT,"="x76);

# +=======================================================================+
# || check if the LDAP is there                                          ||
# +=======================================================================+
if($cibot_ldap_status eq 'offline'){
  &cat_header($remote_user,\&header,\&help_search_link,\&text);
  print &cat_error(&text('_error_no_ldap_connect'));
  exit(0);
}

&cibot_get_ldap_config();
&log($SCRIPT,"- remote user [$remote_user]");

my ($result,$role) = &cibot_acl($SCRIPT,$remote_user);
&cat_header($remote_user,\&header,\&help_search_link,\&text);

# hostname, user, arrayref
print &cat_status_line(&get_system_hostname(),
                       "$remote_user ($role) -> $result",
		       [
			&text('server'),
			&text('status'),
			$cipux{Customer},
			&text('date'),
			&text('version'),
                        $ldap{CipUX}{CipUX_Institution_Name}
		       ]
		      );

# +=======================================================================+
# ||  CAT ACL check                                                      ||
# +=======================================================================+
if($result ne 'ok'){
  print "<h1>".&text('access_denied')."</h1>";
  my $error = &text('access_denied_explanation',
                   "<b>$remote_user</b>",
                   "<b>$role</b>");
  &log($SCRIPT,$error);
  print &cat_error($error);
  &cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});
  exit(0)
}

# +=======================================================================+
# || Environment                                                         ||
# +=======================================================================+
&log($SCRIPT,"ReadParse...");
ReadParse();# webmin

my $system = $in{'system'}    if defined($in{'system'});# system

foreach(sort keys %in){
  &log($SCRIPT,"- IN: [$_] = [$in{$_}]") if defined($in{$_});
}

# =========================================================================+
# ||                         Main                                         ||
# =========================================================================+
print "<h2>".&text('setup')." ($remote_user as $role)</h2>";

if(not defined($in{question})){
  print " <form method=post action='setup.cgi'>";
  if(defined($ldap{CipUX}{CipUX_Institution_Setup_Done})){
  print &cat_explain_message("  
   Das Setup wird erneut durchgef&uuml;rt und die eingestellten
   Werte &uuml;bersschieben.
  ");

  }else{
  print &cat_explain_message("  
  Vielen Dank f&uuml;r die Nutzung von CipUX/CAT!
   Da CAT zum ersten Mal benuzt wird, m&uuml;ssen jetzt einige
   Einstellungen vorgenommen werden.  Diese werden dann in der
  lokalen Datenbank gespeichert.");
  }
  my $v = "";
  $v = $ldap{CipUX}{CipUX_Institution_Name} if defined($ldap{CipUX}{CipUX_Institution_Name});
  print " Wie hei&szlig;t ihre Institution?";
  print " <input type=text name=institution value='$v'>";
  print " <input type=hidden name=question value=\"2\" >";
  print " <input type=submit name=question_answer value=\"".&text('save')."\">";
  print " </form>";
}
if($in{question} eq "2"){
   my $value = "CipUX_Institution_Name=$in{institution}";
   &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
  print " <form method=post action='setup.cgi'>";
  print " Hat diese Institution ($in{institution}) eine Klassenstruktur, &auml;hnlich einer Schule? <br>";
  print " (d.h. &auml;ndern sich die Klassennamen nach jedem Schuljahr? Beispiel: 2a => 2b )";
  print " <input type=hidden name=institution value=\"$in{institution}\" >";
  print " <input type=hidden name=question value=\"3\" >";
  print " <input type=submit name=question_answer value=\"".&text('yes')."\"> ";
  print " <input type=submit name=question_answer value=\"".&text('no')."\"> ";
  print " </form>";
}
if($in{question} eq "3" and $in{question_answer} eq &text("yes")){
  my $value = "CipUX_Institution_Structure=1";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
  $value="Cat_Feature_Transferadmin=0";
  &cipux_task_change_cipux_config_variable_value('cgi','CAT',$value);
  my $v = "0";
  $v = $ldap{CipUX}{CipUX_Institution_Parallel_Courses} if defined($ldap{CipUX}{CipUX_Institution_Parallel_Courses});
  print " <form method=post action='setup.cgi'>";
  print " Wieviele Z&uuml;ge (Parallel-Gruppen/Klassen/Kurse/Seminare/...) gibt es?<br>";
  print &cat_explain_message("
  Beispiel: <br>Wenn es in jedem Jahrgang die Klassen/Seinare/...  a,b und c gibt,
  (also zum Beispiel 1a, 1b, 1c; 2a, 2b ...), dann lautet die Antwort: '<b>3</b>'.");
  print " <input type=hidden name=question value=\"4\" >";
  print " <input type=hidden name=institution value=\"$in{institution}\" >";
  print " <input type=text name=col_value value='$v'> ";
  print " <input type=submit name=question_answer value=\"".&text('save')."\">";
  print " </form>";
}
if($in{question} eq "3" and $in{question_answer} eq &text("no")){
  # disable transferadmin
  my $value = "CipUX_Institution_Structure=2";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
  $value="Cat_Feature_Transferadmin=0";
  &cipux_task_change_cipux_config_variable_value('cgi','CAT',$value);
  my $value = "CipUX_Institution_Setup_Done=1";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
  print "Setup abgeschlossen";
  $last_question = 1;
}
if($in{question} eq "4"){
  my $value = "CipUX_Institution_Parallel_Courses=$in{col_value}";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
  my $v = "0";
  $v = $ldap{CipUX}{CipUX_Institution_Course_Levels} if defined($ldap{CipUX}{CipUX_Institution_Course_Levels});
  print " <form method=post action='setup.cgi'>";
  print " Wieviele Jahrg&auml;nge gibt es?<br>";
  print &cat_explain_message("
  Beispiel: <br>
  Wenn es die Klassen/Seminare/Kurse/...  2a, 3a, 4a, 5a und 6a gibt, so 
  lautet die Antwort: '<b>5</b>'.
  ",$cb);
  print "<br>";
  print " <input type=hidden name=question value=\"5\" >";
  print " <input type=hidden name=institution value=\"$in{institution}\" >";
  print " <input type=hidden name=col_value value=\"$in{col_value}\" >";
  print " <input type=text   name=row_value value='$v'> ";
  print " <input type=submit name=question_answer value=\"".&text('save')."\">";
  print " </form>";
}
if($in{question} eq "5"){
# print " <form method=post action='setup.cgi'>";
# print " Sind die Angaben richtig?";
# print " <table border=1>";
# print " <tr $tb> <th $tb colspan=2> Institution: $in{institution}</th></tr>";
# print " <tr><th $cb>Prallel Gruppen: </th><td>$in{col_value}</td></tr>";
# print " <tr><th $cb>Jahrg&auml;nge: </th><td>$in{row_value}</td></tr>";
# print " </table>";
# print " <input type=hidden name=institution value=\"$in{institution}\" >";
# print " <input type=hidden name=question value=\"6\" >";
# print " <input type=hidden name=col_value value=\"$in{col_value}\" >";
# print " <input type=hidden name=row_value value=\"$in{row_value}\" >";
# print " <input type=submit name=question_answer value=\"".&text('yes')."\"> ";
# print " <input type=submit name=question_answer value=\"".&text('no')."\"> ";
# print " </form>";
#
#f($in{question} eq "6" and $in{question_answer} eq &text("yes")){
  my $value = "CipUX_Institution_Course_Levels=$in{row_value}";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);


  print " <form method=post action='setup.cgi'>";
  

    print "
    Bitte die Namen der Klassen, Gruppen, Kurse, Seminare, ... eintragen.
    Die Objekte werden dann erzeugt. Das kann etwas dauern.
    Bitte auch &uuml;pr&uuml;fen ob alles richtig geschrieben ist!<br><br>";
   print &cat_explain_message("Beispiel (2 Jahrg&auml;nge, 2 Z&uuml;ge):
   <table border=1><tr><th>Zug:</th><th>1</th><th>2</th></tr>
          <tr><th>Jahrgang 1:</th><td>1a</td><td>1b</td></tr>
          <tr><th>Jahrgang 2:</th><td>2a</td><td>2b</td></tr>
   </table><br>",$cb);

  print "<br>";
  print &cat_table_header($in{col_value}+1,$tb,"Institution : $in{institution}");
 
  my @col = (1..$in{col_value});
  my @row = (1..$in{row_value});
  my @header = ();
  my @normal = ();
  my @color1 = ();
  my @color2 = ();
  my @coln   = ();
  my @rown   = ();
  my $c = 1;
  push(@normal,1);
  push(@header,1);
  push(@color2,$cb);
  push(@color1,$tb);
  push(@coln,'Zug:');
  foreach(@col){
     push(@header,1);
     push(@normal,0);
     push(@color1,$tb);
     push(@color2,'');
     push(@coln,$c);
     $c++;
  }
  $c=1;
  foreach (@row){
    push(@rown,$c);
    $c++;
  }
  print &cat_table_row(\@header,\@color1,\@coln);

  foreach $row (@rown){
    my @line = ();
    push(@line,"Jahrgang $row:");
    foreach $col (@col){
      my $v = "";
      my $f = "CipUX_Institution_Matrix_".$row."_".$col;
      $v = $ldap{CipUX}{$f} if defined($ldap{CipUX}{$f});
      push(@line,"<input type=text name=Matrix:".$row."_".$col." value='$v'>");
    }
    print &cat_table_row(\@normal,\@color2,\@line);
  }
  print &cat_table_footer ."<br>";
  print " <input type=hidden name=question value=\"7\" >";
  print "Voreingestelltes Passwort f&uuml;r obige Klassen/Seminare/Kurse/...:";
  print " <input type=text name=default_password>";
  print " <input type=submit name=question_answer value=\"".&text('save')."\">";
  print " </form>";
}
if($in{question} eq '7'){
  print &cat_explain_message("Bitte warten bis die Seite follst&auml;ndig geladen ist.",$cb);
  print "<ul>";
  foreach my $key (sort keys %in){
    # a relevant key?
    if($key =~ /Matrix:/){
      my $line = $key;
      $line =~ s/Matrix://g;
      my ($row, $col) = split(/_/,$line);

      # add this to structure
      print "<li>"."Trage Jahrgang <b>$row</b> und Zug <b>$col</b> in die Struktur ein.</li>";
      my $value = "CipUX_Institution_Matrix_".$row."_".$col."=".$in{$key};
      &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);

      # create a group
      print "<li>"."Erstelle Objekt <b>$in{$key}</b></li>";
      &cipux_task_create_course('cgi',$in{$key},$in{default_password});
    }
  }
  print "</ul>";

  # set Setup_Ok in ldap server

  # print ok message
  my $value = "CipUX_Institution_Setup_Done=1";
  &cipux_task_change_cipux_config_variable_value('cgi','CipUX',$value);
  print &cat_explain_message("Das Setup wurde durchgef&uuml;hrt.",$cb);
  $last_question = 1;

}




# +=======================================================================+
# || Footer                                                              ||
# +=======================================================================+
if($last_question){
  &cat_footer($remote_user,\&footer,$ldap{CipUX}{Cipux_Support});
}else{
  #&cat_footer($remote_user,\&footer,'');
}

exit(0);

